/*
 * Name:    mx_tcl.h
 *
 * Purpose: TCL interface to the MX library.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 1999-2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MX_TCL_H__
#define __MX_TCL_H__

MX_API mx_status_type mxtcl_get_record_from_object(
					MX_RECORD **record,
					Tcl_Interp *interp,
					Tcl_Obj *CONST obj );

MX_API int mxtcl_error( Tcl_Interp *, mx_status_type mx_status );

MX_API int mxtcl_object_parse_error( Tcl_Interp *interp,
					Tcl_Obj *CONST obj,
					const char *type_name,
					const char *calling_fname );

MX_API mx_status_type mxtcl_process_tcl_events( unsigned long max_events );

MX_API int Mxtcl_Init( Tcl_Interp *interp );

MX_API int Mx_Init( Tcl_Interp *interp );

MX_API int Mxtk_Init( Tcl_Interp *interp );

MX_API int Mx_init_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_debug_level_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_debug_level_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_plotting_is_enabled_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_plot_enable_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

/*===*/

MX_API int Mx_process_exists_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

/*===*/

MX_API int Mx_getch_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_kbhit_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_user_requested_interrupt_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_user_interrupt_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

/*===*/

MX_API int Mx_info_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_info_output_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_warning_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_warning_output_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_error_output_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_debug_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_debug_output_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

/*===*/

MX_API int Mx_info_dialog_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_info_dialog_function_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

/*===*/

MX_API int Mx_create_record_list_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_read_database_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_finish_database_initialization_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_initialize_hardware_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_create_record_from_description_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_finish_record_initialization_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_delete_record_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_record_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_next_record_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_previous_record_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_record_name_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_create_description_from_record_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_field_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_set_field_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_object_class_name_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_version_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_getchar_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_putchar_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_getline_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_putline_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_input_is_available_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_discard_unread_input_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_rs232_discard_unwritten_output_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_digital_input_read_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_digital_output_read_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_digital_output_write_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_is_busy_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_move_absolute_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_position_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_set_position_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_soft_abort_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_immediate_abort_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_positive_limit_hit_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_negative_limit_hit_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_find_home_position_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_constant_velocity_move_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_set_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_base_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_set_base_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_maximum_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_set_maximum_speed_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_acceleration_type_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_get_acceleration_parameters_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_set_acceleration_parameters_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_motor_home_search_succeeded_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_relay_command_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_get_relay_status_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_clear_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_overflow_set_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_read_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_read_raw_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_get_dark_current_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scaler_set_dark_current_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_timer_is_busy_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_timer_start_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_timer_stop_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_scan_perform_scan_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_send_variable_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_receive_variable_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_log_open_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

MX_API int Mx_log_close_cmd( ClientData clientData,
			Tcl_Interp *interp,
			int objc,
			Tcl_Obj *CONST objv[] );

#endif /* __MX_TCL_H__ */

